#[repr(u8)]pub enum ErlangElementType {
Show 93 variants
Whitespace = 0,
Newline = 1,
Comment = 2,
Identifier = 3,
Atom = 4,
Variable = 5,
Number = 6,
String = 7,
Character = 8,
After = 9,
And = 10,
Andalso = 11,
Band = 12,
Begin = 13,
Bnot = 14,
Bor = 15,
Bsl = 16,
Bsr = 17,
Bxor = 18,
Case = 19,
Catch = 20,
Cond = 21,
Div = 22,
End = 23,
Fun = 24,
If = 25,
Let = 26,
Not = 27,
Of = 28,
Or = 29,
Orelse = 30,
Query = 31,
Receive = 32,
Rem = 33,
Try = 34,
When = 35,
Xor = 36,
Plus = 37,
Minus = 38,
Star = 39,
Slash = 40,
Equal = 41,
EqualEqual = 42,
SlashEqual = 43,
EqualColonEqual = 44,
EqualSlashEqual = 45,
Less = 46,
Greater = 47,
LessEqual = 48,
GreaterEqual = 49,
PlusPlus = 50,
MinusMinus = 51,
Exclamation = 52,
Question = 53,
LeftParen = 54,
RightParen = 55,
LeftBrace = 56,
RightBrace = 57,
LeftBracket = 58,
RightBracket = 59,
Comma = 60,
Semicolon = 61,
Dot = 62,
Colon = 63,
Arrow = 64,
Pipe = 65,
PipePipe = 66,
Hash = 67,
Root = 68,
Item = 69,
Module = 70,
Export = 71,
Attribute = 72,
Function = 73,
FunctionClause = 74,
Pattern = 75,
RecordPattern = 76,
Statement = 77,
Expr = 78,
BinaryExpr = 79,
CallExpr = 80,
FunExpr = 81,
CaseExpr = 82,
CaseClause = 83,
IfExpr = 84,
IfClause = 85,
TryExpr = 86,
CatchClause = 87,
ReceiveExpr = 88,
ReceiveClause = 89,
RecordExpr = 90,
Error = 91,
Eof = 92,
}Expand description
Element types for the Erlang language.
Variants
Whitespace = 0
Whitespace characters.
Newline = 1
Newline characters.
Comment = 2
Comments.
Identifier = 3
Identifiers.
Atom = 4
Atoms.
Variable = 5
Variables.
Number = 6
Numbers.
String = 7
Strings.
Character = 8
Characters.
After = 9
after keyword.
And = 10
and keyword.
Andalso = 11
andalso keyword.
Band = 12
band keyword.
Begin = 13
begin keyword.
Bnot = 14
bnot keyword.
Bor = 15
bor keyword.
Bsl = 16
bsl keyword.
Bsr = 17
bsr keyword.
Bxor = 18
bxor keyword.
Case = 19
case keyword.
Catch = 20
catch keyword.
Cond = 21
cond keyword.
Div = 22
div keyword.
End = 23
end keyword.
Fun = 24
fun keyword.
If = 25
if keyword.
Let = 26
let keyword.
Not = 27
not keyword.
Of = 28
of keyword.
Or = 29
or keyword.
Orelse = 30
orelse keyword.
Query = 31
query keyword.
Receive = 32
receive keyword.
Rem = 33
rem keyword.
Try = 34
try keyword.
When = 35
when keyword.
Xor = 36
xor keyword.
Plus = 37
Plus operator (+).
Minus = 38
Minus operator (-).
Star = 39
Star operator (*).
Slash = 40
Slash operator (/).
Equal = 41
Equal operator (=).
EqualEqual = 42
EqualEqual operator (==).
SlashEqual = 43
SlashEqual operator (/=).
EqualColonEqual = 44
EqualColonEqual operator (=:=).
EqualSlashEqual = 45
EqualSlashEqual operator (=/=).
Less = 46
Less operator (<).
Greater = 47
Greater operator (>).
LessEqual = 48
LessEqual operator (=<).
GreaterEqual = 49
GreaterEqual operator (>=).
PlusPlus = 50
PlusPlus operator (++).
MinusMinus = 51
MinusMinus operator (--).
Exclamation = 52
Exclamation operator (!).
Question = 53
Question operator (?).
LeftParen = 54
Left parenthesis (().
RightParen = 55
Right parenthesis ()).
LeftBrace = 56
Left brace ({).
RightBrace = 57
Right brace (}).
LeftBracket = 58
Left bracket ([).
RightBracket = 59
Right bracket (]).
Comma = 60
Comma (,).
Semicolon = 61
Semicolon (;).
Dot = 62
Dot (.).
Colon = 63
Colon (:).
Arrow = 64
Arrow (->).
Pipe = 65
Pipe (|).
PipePipe = 66
PipePipe (||).
Hash = 67
Hash (#).
Root = 68
Root node of the Erlang AST.
Item = 69
An item in the module.
Module = 70
Module declaration.
Export = 71
Export attribute.
Attribute = 72
Generic attribute.
Function = 73
Function declaration.
FunctionClause = 74
A clause of a function.
Pattern = 75
A pattern matching expression.
RecordPattern = 76
A record pattern.
Statement = 77
A statement.
Expr = 78
An expression.
BinaryExpr = 79
A binary expression.
CallExpr = 80
A function call.
FunExpr = 81
A fun expression.
CaseExpr = 82
A case expression.
CaseClause = 83
A clause in a case expression.
IfExpr = 84
An if expression.
IfClause = 85
A clause in an if expression.
TryExpr = 86
A try expression.
CatchClause = 87
A catch clause.
ReceiveExpr = 88
A receive expression.
ReceiveClause = 89
A clause in a receive expression.
RecordExpr = 90
A record expression.
Error = 91
Error node.
Eof = 92
End of file.
Implementations
Sourceimpl ErlangElementType
impl ErlangElementType
Sourcepub fn is_keyword(&self) -> bool
pub fn is_keyword(&self) -> bool
Returns true if the element type is a keyword.
Sourcepub fn is_operator(&self) -> bool
pub fn is_operator(&self) -> bool
Returns true if the element type is an operator.
Sourcepub fn is_punctuation(&self) -> bool
pub fn is_punctuation(&self) -> bool
Returns true if the element type is a punctuation.